@@ -1,6 +1,6 @@
-# coding=utf-8
 import sys
 from io import BytesIO
+from pyredis.exceptions import ProtocolError, ReplyError
 
 SYM_CRLF = b'\r\n'
 SYM_EMPTY = b''
@@ -16,8 +16,6 @@ __all__ = [
     'writer'
 ]
 
-from pyredis.exceptions import ProtocolError, ReplyError
-
 
 def is_exception(inst, classinfo):
     try:
@@ -29,13 +27,11 @@ def is_exception(inst, classinfo):
         if isinstance(inst('test'), classinfo):
             return True
         else:
-            raise TypeError('{0} is not a subclass of {1}'
-                            .format(inst, classinfo))
+            raise TypeError('{0} is not a subclass of {1}'.format(inst, classinfo))
 
 
 class ReplyParser(object):
-    def __init__(self, encoding, source, protocol_error=ProtocolError,
-                 reply_error=ReplyError):
+    def __init__(self, encoding, source, protocol_error=ProtocolError, reply_error=ReplyError):
         self._len = 0
         self._nested_parser = None
         self._encoding = encoding
@@ -70,8 +66,7 @@ class ReplyParser(object):
         elif byte == SYM_EMPTY:
             return None
         else:
-            raise self._protocol_error('Protocol error, got {0} as reply type byte'
-                                       .format(byte))
+            raise self._protocol_error('Protocol error, got {0} as reply type byte'.format(byte))
 
     def parse(self):
         while not self.complete:
@@ -167,8 +162,7 @@ class ReplyParser(object):
 
 
 class Reader(object):
-    def __init__(self, encoding=None, protocolError=ProtocolError,
-                 replyError=ReplyError):
+    def __init__(self, encoding=None, protocolError=ProtocolError, replyError=ReplyError):
         self._buffer = BytesIO()
         self._buffer_pos = 0
         self._encoding = encoding
@@ -233,7 +227,7 @@ def to_bytes(value):
 
 
 def writer(*args):
-    buf = []
+    buf = list()
 
     buf.append(TYPE_ARRAY)
     buf.append(to_bytes(len(args)))
@@ -250,5 +244,3 @@ def writer(*args):
         buf.append(SYM_CRLF)
 
     return b''.join(buf)
-
-
